@@ -1,3 +1,6 @@
+#!/usr/bin/env python
+
+import vinca
 # imports
 from pathlib import Path
 from subprocess import run
@@ -22,7 +25,7 @@ from . import browser
 vinca_path = Path(__file__) # /path/to/vinca/__init__.py
 vinca_path = vinca_path.parent # /path/to/vinca
 cards_path = vinca_path / 'cards'
-decks_path = vinca_path / 'cards.txt'
+decks_path = vinca_path / 'decks.txt'
 decks_vimrc = vinca_path / 'decks.vimrc'
 
 
